from django.forms import (
    ModelForm,
    Textarea,
    SelectMultiple,
    HiddenInput,
    DateInput as BaseDateInput,
)
from .models import Stair, Transmittal


class NoteInput(Textarea):
    def __init__(self, attrs=None):
        if attrs is None:
            attrs = {}
        super().__init__(
            attrs={
                'class': 'note-input',
                'rows': 2,
                # 'cols': 20,
            }
        )

class StairScopeRowForm(ModelForm):
    class Meta:
        model = Stair
        fields = [
            'name',
            'alt_name',
            'grid',
            'levels',
            'flights',
            'stringer_type',
            'stringer_custom',
            'stair_con',
            'stair_con_custom',
            'stair_qt',
            'landings',
            'land_con',
            'land_con_custom',
            'land_qt',
            'rail_type',
            'rail_type_custom',
            'finish',
            'finish_custom',
            'stn',
            'stn_note',
            'submittal',
        ]
        widgets = {
            # 'alt_name': NoteInput(),
            # 'stringer_custom': NoteInput(),
            # 'stair_con_custom': NoteInput(),
            # 'land_con_custom': NoteInput(),
            # 'rail_type_custom': NoteInput(),
            # 'finish_custom': NoteInput(),
            'stn_note': NoteInput(),
        }

class DateInput(BaseDateInput):
    input_type = 'date'

    def __init__(self, attrs=None):
        if attrs is None:
            attrs = {}
        attrs['class'] = 'form-control'
        super().__init__(attrs=attrs)

class TransmittalForm(ModelForm):
    class Meta:
        model = Transmittal
        fields = [
            'job',
            'stairs',
            'description',
            'to_engr',
            'due_from_engr',
            'rec_from_engr',
            'submitted',
            'rec_from_cust',
            'response',
            'for_record',
        ]
        widgets = {
            'job': HiddenInput(),
            'stairs': SelectMultiple(attrs={'class': 'w-100 select2'}),
            'to_engr': DateInput(),
            'due_from_engr': DateInput(),
            'rec_from_engr': DateInput(),
            'submitted': DateInput(),
            'rec_from_cust': DateInput(),
        }

def make_transmittal_form(job):
    stairs = job.get_stairs()
    initial = dict(stairs=[s.pk for s in stairs], job=job)
    form = TransmittalForm(initial)
    form.fields['stairs'].choices = [(s.pk, s.unique_name()) for s in stairs]
    return form
    
class StairFabCalendarForm(ModelForm):
    class Meta:
        model = Stair
        fields = [
            'stair_fabs',
        ]
